==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_ZipNotifier.h <==
//----------------------------------------------------------------------------
// wxZipNotifier
// extracted from zipstrm.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_ZIPNOTIFIER_H__
#define __CLASS_WX_ZIPNOTIFIER_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxZipNotifier
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_ZipNotifier);

//----------------------------------------------------------------------------
// Object declaration for wxZipNotifier
//----------------------------------------------------------------------------
class Object_wx_ZipNotifier : public Object {
protected:
	wxZipNotifier *_pEntity;
	GuraObjectObserver *_pObserver;
	bool _ownerFlag;
public:
	Gura_DeclareObjectAccessor(wx_ZipNotifier)
public:
	inline Object_wx_ZipNotifier(wxZipNotifier *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object(Gura_UserClass(wx_ZipNotifier)),
				_pEntity(pEntity), _pObserver(pObserver), _ownerFlag(ownerFlag) {}
	inline Object_wx_ZipNotifier(Class *pClass, wxZipNotifier *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object(pClass), _pEntity(pEntity), _pObserver(pObserver), _ownerFlag(ownerFlag) {}
	virtual ~Object_wx_ZipNotifier();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline void SetEntity(wxZipNotifier *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) {
		if (_ownerFlag) delete _pEntity;
		_pEntity = pEntity;
		_pObserver = pObserver;
		_ownerFlag = ownerFlag;
	}
	inline void InvalidateEntity() { _pEntity = NULL, _pObserver = NULL, _ownerFlag = false; }
	inline wxZipNotifier *GetEntity() { return _pEntity; }
	inline wxZipNotifier *ReleaseEntity() {
		wxZipNotifier *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline void NotifyGuraObjectDeleted() {
		if (_pObserver != NULL) _pObserver->GuraObjectDeleted();
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxZipNotifier");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_ZipNotifier.h <==
//----------------------------------------------------------------------------
// wxZipNotifier
// extracted from zipstrm.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_ZIPNOTIFIER_H__
#define __CLASS_WX_ZIPNOTIFIER_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxZipNotifier
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_ZipNotifier);

//----------------------------------------------------------------------------
// Object declaration for wxZipNotifier
//----------------------------------------------------------------------------
class Object_wx_ZipNotifier : public Object {
protected:
	wxZipNotifier *_pEntity;
	GuraObjectObserver *_pObserver;
	bool _ownerFlag;
public:
	Gura_DeclareObjectAccessor(wx_ZipNotifier)
public:
	inline Object_wx_ZipNotifier(wxZipNotifier *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object(Gura_UserClass(wx_ZipNotifier)),
				_pEntity(pEntity), _pObserver(pObserver), _ownerFlag(ownerFlag) {}
	inline Object_wx_ZipNotifier(Class *pClass, wxZipNotifier *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object(pClass), _pEntity(pEntity), _pObserver(pObserver), _ownerFlag(ownerFlag) {}
	virtual ~Object_wx_ZipNotifier();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline void SetEntity(wxZipNotifier *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) {
		if (_ownerFlag) delete _pEntity;
		_pEntity = pEntity;
		_pObserver = pObserver;
		_ownerFlag = ownerFlag;
	}
	inline void InvalidateEntity() { _pEntity = nullptr, _pObserver = nullptr, _ownerFlag = false; }
	inline wxZipNotifier *GetEntity() { return _pEntity; }
	inline wxZipNotifier *ReleaseEntity() {
		wxZipNotifier *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline void NotifyGuraObjectDeleted() {
		if (_pObserver != nullptr) _pObserver->GuraObjectDeleted();
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxZipNotifier");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
